package com.hungraim.ltc.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.disable.*;
import com.hungraim.ltc.pojo.vo.disable.DisableExamineInfoVO;
import com.hungraim.ltc.pojo.vo.disable.DisableInfoVO;
import com.hungraim.ltc.pojo.vo.disable.DisableVO;
import com.hungraim.ltc.pojo.vo.disable.DistrictTreeVo;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 失能申请Service
 *
 * @author czz
 */
@Service
public interface DisableService {


    Page<DisableVO> disableList(String organId, String districtProvincial, String districtCity,
                                String districtArea, String realName, String certiCode, String dataFrom,
                                String srvOrganName, int pageNum, int pageSize);

    /**
     * 失能审核信息详情
     *
     * @param applyId 申请id
     * @return 失能审核信息详情
     */
    DisableExamineInfoVO disableExamineInfo(String applyId);

    void addDisable(ChDisableApply chDisableApply);

    void disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark);

    /**
     * 省市区
     *
     * @param districtLevel 区域级别:1省2地级市3县
     * @param districtCode  上级区域代码
     */
    List<ChFndDistrict> district(String districtLevel, String districtCode);

    List<ChFndOrgan> fndOrganRoot();

    /**
     * 查询所有服务方式
     */
    List<ChFndSrvMode> fndSrvModeList();

    /**
     * 查询机构下所有护理机构
     *
     * @param organId 机构id
     */
    List<ChSrvOrgan> srvOrganList(String organId);

    /**
     * 查询疾病类型
     *
     * @param parDiseTypeId 父疾病类型id
     */
    List<ChFndDiseaseType> fndDiseaseList(String parDiseTypeId);

    /**
     * 查询护理机构下所有子机构id
     *
     * @param organId 机构id
     * @return 机构及所有子机构id, 以逗号分隔, 如果没有子机构则只返回机构id
     */
    String subsidiariesOrganId(String organId);

    void updateDisable(ChDisableApply chDisableApply);

    /**
     * 获取所有省市区街道数据
     *
     * @return 返回树形结构省市区数据
     */
    List<DistrictTreeVo> allDistrict();

    /**
     * 获取所有省市区街道数据，以树形结构返回
     *
     * @return 返回树形结构省市区数据
     */
    List<DistrictTreeVo> getAllDistrictTreeData();

    /**
     * 查询所有疾病数据
     */
    List<ChFndDiseaseType> fndAllDisease();

    DisableInfoVO getDisableInfo(String disableInfoId);
}
