package com.hungraim.ltc.governance.service.impl;

import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.hungraim.ltc.governance.dao.ChCfgAprItemClauseMapper;
import com.hungraim.ltc.governance.dao.ChCfgAprItemMapper;
import com.hungraim.ltc.governance.dao.ChCfgAprMapper;
import com.hungraim.ltc.governance.service.DisableAssessmentCriteriaService;
import com.hungraim.ltc.pojo.entity.assessment.ChCfgApr;
import com.hungraim.ltc.pojo.entity.assessment.ChCfgAprItem;
import com.hungraim.ltc.pojo.entity.assessment.ChCfgAprItemClause;
import com.hungraim.ltc.pojo.vo.governance.CfgAprVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * 失能评定标准service
 *
 * @author czz
 */
@Service
public class DisableAssessmentCriteriaServiceImpl implements DisableAssessmentCriteriaService {

    @Autowired
    private ChCfgAprMapper chCfgAprMapper;
    @Autowired
    private ChCfgAprItemMapper chCfgAprItemMapper;
    @Autowired
    private ChCfgAprItemClauseMapper chCfgAprItemClauseMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addOrUpdateDisableAssessmentCriteria(Long aprId, String organId, String estimateName, String remark, Integer status, JSONArray project) {
        Date date = new Date();
        if (aprId != null) {//编辑
            updateDisableAssessmentCriteria(aprId, organId, estimateName, remark, status, project, date);
        } else {//新增
            addDisableAssessmentCriteria(organId, estimateName, remark, status, project, date);
        }
    }

    /**
     * 失能评定标准定义新增
     */
    private void addDisableAssessmentCriteria(String organId, String estimateName, String remark, Integer status, JSONArray project, Date date) {
        //鉴定标准配置
        ChCfgApr apr = new ChCfgApr();
        apr.setOrganId(organId);
        apr.setEstimateName(estimateName);
        apr.setRemark(remark);
        apr.setEffTime(date);
        apr.setStatus(status.shortValue());
        chCfgAprMapper.insert(apr);
        //鉴定项目定义
        for (int i = 0; i < project.size(); i++) {
            ChCfgAprItem item = new ChCfgAprItem();
            JSONObject itemObject = project.getJSONObject(i);
            String projectNama = itemObject.getStr("projectNama");
            String minVal = itemObject.getStr("minVal");
            String maxVal = itemObject.getStr("maxVal");
            item.setItemName(projectNama);
            item.setMinValue(Short.parseShort(minVal));
            item.setMaxValue(Short.parseShort(maxVal));
            item.setAprId(apr.getAprId());
            chCfgAprItemMapper.insert(item);
            //鉴定项目定义明细
            JSONArray projectScoreCriteria = itemObject.getJSONArray("projectScoreCriteria");
            for (int j = 0; j < projectScoreCriteria.size(); j++) {
                ChCfgAprItemClause clause = new ChCfgAprItemClause();
                JSONObject clauseObject = projectScoreCriteria.getJSONObject(j);
                String criteria = clauseObject.getStr("criteria");
                String reference = clauseObject.getStr("reference");
                clause.setClauseDesc(criteria);
                clause.setClauseValue(Short.parseShort(reference));
                clause.setItemId(item.getItemId());
                clause.setAprId(apr.getAprId());
                chCfgAprItemClauseMapper.insert(clause);
            }
        }
    }

    /**
     * 失能评定标准定义编辑
     */
    private void updateDisableAssessmentCriteria(Long aprId, String organId, String estimateName, String remark, Integer status, JSONArray project, Date date) {
        //鉴定标准配置
        ChCfgApr chCfgApr = chCfgAprMapper.selectById(aprId);
        chCfgApr.setOrganId(organId);
        chCfgApr.setEstimateName(estimateName);
        chCfgApr.setRemark(remark);
        if (chCfgApr.getFcd() == null) {
            chCfgApr.setFcd(date);//首次操作时间
        }
        chCfgApr.setLcd(date);
        chCfgApr.setStatus(status.shortValue());
        chCfgAprMapper.updateById(chCfgApr);
        //鉴定项目
        List<ChCfgAprItem> itemList = chCfgAprItemMapper.selectList(new QueryWrapper<ChCfgAprItem>().eq("apr_id", aprId));
        for (int i = 0; i < project.size(); i++) {
            JSONObject itemObject = project.getJSONObject(i);
            Long itemId = itemObject.getLong("itemId");
            String projectNama = itemObject.getStr("projectNama");
            String minVal = itemObject.getStr("minVal");
            String maxVal = itemObject.getStr("maxVal");
            if (itemId != null) {
                //修改id对应的鉴定项目
                boolean flag = false;
                for (ChCfgAprItem item : itemList) {
                    if (Objects.equals(item.getItemId(), itemId)) {
                        if (item.getFcd() == null) {
                            item.setFcd(date);//首次操作时间
                        }
                        item.setItemName(projectNama);
                        item.setMinValue(Short.parseShort(minVal));
                        item.setMaxValue(Short.parseShort(maxVal));
                        chCfgAprItemMapper.updateById(item);
                        itemList.remove(item);
                        flag = true;
                    }
                }
                if (!flag) {
                    throw new RuntimeException("无效的itemId!");
                }
                //鉴定项目定义明细
                List<ChCfgAprItemClause> itemClauseList = chCfgAprItemClauseMapper.selectList(new QueryWrapper<ChCfgAprItemClause>().eq("item_id", itemId));
                JSONArray projectScoreCriteria = itemObject.getJSONArray("projectScoreCriteria");
                for (int j = 0; j < projectScoreCriteria.size(); j++) {
                    ChCfgAprItemClause clause = new ChCfgAprItemClause();
                    JSONObject clauseObject = projectScoreCriteria.getJSONObject(j);
                    Long clauseId = clauseObject.getLong("clauseId");
                    String criteria = clauseObject.getStr("criteria");
                    String reference = clauseObject.getStr("reference");
                    if (clauseId != null) {
                        flag = false;
                        for (ChCfgAprItemClause item : itemClauseList) {
                            if (Objects.equals(item.getClauseId(), clauseId)) {
                                if (item.getFcd() == null) {
                                    item.setFcd(date);//首次操作时间
                                }
                                clause.setClauseDesc(criteria);
                                clause.setClauseValue(Short.parseShort(reference));
                                clause.setItemId(itemId);
                                clause.setAprId(aprId);
                                chCfgAprItemClauseMapper.updateById(clause);
                                itemClauseList.remove(item);
                                flag = true;
                            }
                        }
                        if (!flag) {
                            throw new RuntimeException("无效的clauseId!");
                        }
                    } else {
                        ChCfgAprItemClause cl = new ChCfgAprItemClause();
                        cl.setClauseDesc(criteria);
                        cl.setClauseValue(Short.parseShort(reference));
                        cl.setItemId(itemId);
                        cl.setAprId(aprId);
                        chCfgAprItemClauseMapper.insert(cl);
                    }
                }
                //删除多余的评定项目明细
                for (ChCfgAprItemClause item : itemClauseList) {
                    chCfgAprItemClauseMapper.deleteById(item);
                }
            } else {
                //没有对应的鉴定项目就新增
                ChCfgAprItem item = new ChCfgAprItem();
                item.setItemName(projectNama);
                item.setMinValue(Short.parseShort(minVal));
                item.setMaxValue(Short.parseShort(maxVal));
                item.setAprId(aprId);
                chCfgAprItemMapper.insert(item);
                //鉴定项目定义明细
                JSONArray projectScoreCriteria = itemObject.getJSONArray("projectScoreCriteria");
                for (int j = 0; j < projectScoreCriteria.size(); j++) {
                    ChCfgAprItemClause clause = new ChCfgAprItemClause();
                    JSONObject clauseObject = projectScoreCriteria.getJSONObject(j);
                    String criteria = clauseObject.getStr("criteria");
                    String reference = clauseObject.getStr("reference");
                    clause.setClauseDesc(criteria);
                    clause.setClauseValue(Short.parseShort(reference));
                    clause.setItemId(item.getItemId());
                    clause.setAprId(aprId);
                    chCfgAprItemClauseMapper.insert(clause);
                }
            }
        }
        //删除多余的评定项目
        for (ChCfgAprItem item : itemList) {
            chCfgAprItemMapper.deleteById(item);
        }
    }

    @Override
    public List<CfgAprVO> getDisableAssessmentCriteriaList(String organIds, String aprName, String status) {
        List<String> organIdList = null;
        if (StrUtil.isNotBlank(organIds)) {
            organIdList = Arrays.asList(organIds.split(","));
        }
        return chCfgAprMapper.getDisableAssessmentCriteriaList(organIdList, aprName, status);
    }

    @Override
    public void stopDisableAssessmentCriteria(String aprId) {
        ChCfgApr chCfgApr = chCfgAprMapper.selectById(aprId);
        chCfgApr.setStatus((short) 0);
        chCfgAprMapper.updateById(chCfgApr);
    }
}
