package com.hungraim.ltc.governance.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.hungraim.ltc.governance.dao.ChSrvTaskDetailMapper;
import com.hungraim.ltc.governance.dao.SrvTaskMapper;
import com.hungraim.ltc.governance.service.SrvTaskService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvTask;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvTaskDetail;
import com.hungraim.ltc.pojo.vo.governance.SrvTaskInfoVO;
import com.hungraim.ltc.pojo.vo.governance.SrvTaskVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * 服务计划ServiceImpl
 */
@Service
public class SrvTaskServiceImpl implements SrvTaskService {
    @Autowired
    private SrvTaskMapper srvTaskMapper;
    @Autowired
    private ChSrvTaskDetailMapper chSrvTaskDetailMapper;

    /**
     * 服务计划列表
     *
     * @param organId     护理机构id
     * @param disableName 失能人员姓名
     * @param disableTel  失能人员手机号码
     * @param empName     护理人员姓名
     * @param certifNum   护理人员证件号码
     * @param startTime   服务计划开始时间
     * @param endTime     服务计划结束时间
     * @param status      任务状态
     * @param modeId      服务方式
     */
    @Override
    public List<SrvTaskVO> getSrvTaskList(Integer organId, String disableName, String disableTel,
                                          String empName, String certifNum, String startTime, String endTime,
                                          String status, String modeId) {
        return srvTaskMapper.getSrvTaskList(organId, disableName, disableTel, empName, certifNum, startTime, endTime, status, modeId);
    }

    /**
     * 查询服务计划制定详情
     *
     * @param taskId 服务计划id
     */
    @Override
    public SrvTaskInfoVO getSrvTaskInfo(String taskId) {
        return srvTaskMapper.getSrvTaskInfo(taskId);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addSrvTask(Long programId, Long srvEmpId, Date startTime, Date endTime) {
        try {
            //添加服务计划
            ChSrvTask chSrvTask = new ChSrvTask();
            chSrvTask.setEffTime(new Date());//创建时间
            chSrvTask.setProgramId(programId);//服务方案id
            chSrvTask.setSrvEmpId(srvEmpId);//服务人员id
            chSrvTask.setStatus((short) 0);//状态 未分配：0；已分配：1
            int insert = srvTaskMapper.insert(chSrvTask);
            if (insert <= 0) {
                throw new RuntimeException("添加服务计划失败!");
            }
            //添加服务计划详情
            ChSrvTaskDetail chSrvTaskDetail = new ChSrvTaskDetail();
            chSrvTaskDetail.setSrvTaskId(chSrvTask.getSrvTaskId());
            chSrvTaskDetail.setSrvStartTime(startTime);//服务开始时间
            chSrvTaskDetail.setEndTime(endTime);//服务结束时间
            chSrvTaskDetail.setStatus((short) 0);//状态 未执行：0；执行中：1；已执行:2;已失效：3已完成4
            int insert1 = chSrvTaskDetailMapper.insert(chSrvTaskDetail);
            if (insert1 <= 0) {
                throw new RuntimeException("添加服务计划详情失败!");
            }
        } catch (Exception e) {
            throw new RuntimeException("系统繁忙,请稍后再试!");
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void updateSrvTask(String taskId, Long srvEmpId, Date startTime, Date endTime) {
        //修改服务计划服务人员
        ChSrvTask chSrvTask = srvTaskMapper.selectById(taskId);
        if (chSrvTask == null) {
            throw new RuntimeException("修改失败,不存在的服务计划!");
        }
        chSrvTask.setSrvEmpId(srvEmpId);
        int i = srvTaskMapper.updateById(chSrvTask);
        if (i <= 0) {
            throw new RuntimeException("修改服务计划服务人员失败!");
        }
        //修改服务计划详情计划起止日期
        ChSrvTaskDetail chSrvTaskDetail = chSrvTaskDetailMapper.selectOne(new QueryWrapper<ChSrvTaskDetail>().eq("srv_task_id", chSrvTask.getSrvTaskId()));
        chSrvTaskDetail.setSrvStartTime(startTime);
        chSrvTaskDetail.setEndTime(endTime);
        int i1 = chSrvTaskDetailMapper.updateById(chSrvTaskDetail);
        if (i1 <= 0) {
            throw new RuntimeException("修改服务计划详情计划起止日期失败!");
        }
    }
}
